# scellop
This is the Python package for _[scellop](https://github.com/hms-dbmi/scellop/)_, the scalable interactive cell population viewer. It contains data loading functionality and the scellop widget, which is implemented with [anywidget](https://github.com/manzt/anywidget/). 

## Using the scellop widget
Install scellop as 
```python
!pip install scellop
```

Example usage is shown in [example.ipynb](https://github.com/hms-dbmi/scellop/blob/main/python/example.ipynb).

## Contributing to scellop
We encourage contributions! Please find more info in the [contributing guidelines](https://github.com/hms-dbmi/scellop/blob/main/python/CONTRIBUTING.md).